@@ -5,7 +5,7 @@
 /** @fileoverview Suite of tests for extension-item. */
 
 import type {CrIconElement, ExtensionsItemElement} from 'chrome://extensions/extensions.js';
-import {Mv2ExperimentStage, navigation, Page} from 'chrome://extensions/extensions.js';
+import {Mv2ExperimentStage, navigation, Page, TooltipPosition} from 'chrome://extensions/extensions.js';
 import {loadTimeData} from 'chrome://resources/js/load_time_data.js';
 import {assertDeepEquals, assertEquals, assertFalse, assertTrue} from 'chrome://webui-test/chai_assert.js';
 import {isChildVisible, microtasksFinished} from 'chrome://webui-test/test_util.js';
@@ -662,6 +662,7 @@ suite('ExtensionItemTest', function() {
     assertEquals(
         loadTimeData.getString('enableToggleTooltipEnabled'),
         crTooltip.textContent!.trim());
+    assertEquals(TooltipPosition.LEFT, crTooltip.getAttribute('position'));
 
     let data = createExtensionInfo(item.data);
     data.permissions = {
@@ -683,6 +684,19 @@ suite('ExtensionItemTest', function() {
         crTooltip.textContent!.trim());
   });
 
+  test('EnableExtensionToggleTooltipPositions', () => {
+    let crTooltip =
+        item.shadowRoot.querySelector<HTMLElement>('#enable-toggle-tooltip')!;
+    assertEquals(TooltipPosition.LEFT, crTooltip.getAttribute('position'));
+
+    document.dir = 'rtl';
+    const rtlItem = document.createElement('extensions-item');
+    document.body.appendChild(rtlItem);
+    crTooltip = rtlItem.shadowRoot.querySelector<HTMLElement>(
+        '#enable-toggle-tooltip')!;
+    assertEquals(TooltipPosition.RIGHT, crTooltip.getAttribute('position'));
+  });
+
   test('CanUploadAsAccountExtension', async () => {
     testVisible(item, '#account-upload-button', false);
 
